TrendRunmed <- structure(function(
	##title<< 
	## Trend estimation based on a running median
	
	##description<<
	## The function computes a non-linear trend based a running median.
	
	Yt,
	### univariate time series of class \code{\link{ts}}
	
	k=NULL,
	### integer width of median window; must be odd. If NULL a window size of 20 years (i.e. frequency * 20) will be used.
	
	...
	### additional arguments (currently not used)
	
	##seealso<<
	## \code{\link{stl}}
) {
	# get time series properties
	freq <- frequency(Yt)
	start <- start(Yt)
	end <- end(Yt)
	time <- time(Yt)	
	n <- length(Yt)

	if (is.null(k)) k <- freq * 10
	if (k %% 2 == 0) k <- k + 1
		
	# do initial linear interpolation and initial gap filling
	Na <- ts(is.na(Yt), start=start, end=end, frequency=freq)
	Yt2 <- c(rep(Yt[1:freq], n/freq), Yt, rep(Yt[(n-freq+1):n], n/freq))
	Tt <- runmed(Yt2, k)
	Tt <- ts(runmed(Tt[(n+1):(n+n)], 3), start=start, end=end, frequency=freq)
	Tt[Na == 1] <- NA	
	
	# results: pvalue with MannKendall test
	mk <- MannKendall(Tt)
	mk.pval <- mk$sl 
	mk.tau <- mk$tau
	slope_unc <- data.frame(.id=1, NA, NA, NA)
	pval_unc <- data.frame(.id=1, NA, NA, NA)
	tau_unc <- data.frame(.id=1, NA, NA, NA)
	
	# return results
	result <- list(
		series = Yt,
		trend = Tt,
		time = as.vector(time),
		bp = NoBP(),
		slope = NA,
		slope_unc = slope_unc,
		pval = mk.pval,
		pval_unc = pval_unc,
		tau = mk.tau,
		tau_unc = tau_unc,
		bptest = NULL,
		method = "Runmed")
	class(result) <- "Trend"
	return(result)
	### The function returns a list of class "Trend". 
}, ex=function(){
# load a time series of NDVI (normalized difference vegetation index)
data(ndvi)
plot(ndvi)
	
# calculate trend on mean annual NDVI values
trd <- TrendRunmed(ndvi)
trd
plot(trd)

})

